#
# spec file for package grepmail
#
# Copyright (c) 2017 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           grepmail
Version:        5.3104
Release:        3.1
Summary:        Search Mailboxes for a Particular E-Mail
License:        GPL-2.0+
Group:          Productivity/Networking/Email/Utilities
URL:            https://metacpan.org/release/grepmail
Source:         http://search.cpan.org/CPAN/authors/id/D/DC/DCOPPIT/grepmail-%{version}.tar.gz
Patch2:         grepmail-buildfix.patch
BuildRequires:  perl
BuildRequires:  perl-macros
BuildRequires:  perl(Date::Parse)
BuildRequires:  perl(File::Slurp)
BuildRequires:  perl(Mail::Mbox::MessageParser) >= 1.4001
BuildRequires:  perl(Time::Local)
BuildRequires:  perl(URI::Escape)
## not in factory ## BuildRequires:  perl(Benchmark::Timer) => 0.7100
Requires:       perl(Date::Parse)
Requires:       perl(Mail::Mbox::MessageParser) >= 1.4001
Requires:       perl(Time::Local)
# Date::Manip is only used as fallback
Recommends:     perl(Date::Manip)
BuildArch:      noarch
%{perl_requires}

%description
Grepmail searches a normal, gzipped, bzipped, or tzipped mailbox for a
given regular expression, and returns any e-mails that match that
expression. Piped input is allowed and date restrictions are supported.

%prep
%setup -q
sed -i -e 's/use inc::Module::Install;/use lib q[.];\nuse inc::Module::Install;/' Makefile.PL
%if 0%{?suse_version} <= 1320
# needed for <= 13.2, but breaks 'make test' in > 13.2
%patch -P 2
%endif
rm inc/Scalar/Util.pm
%if 0%{?suse_version} >= 1320
rm -rf inc/File/Spec*
%endif

%build
PERL_EXTUTILS_AUTOINSTALL=--skip perl Makefile.PL INSTALLDIRS=site
make %{?_smp_mflags}

%check
make %{?_smp_mflags} test

%install
%perl_make_install
# do not perl_process_packlist (noarch)
# remove .packlist file
rm -rf %{buildroot}%{perl_vendorarch}
# remove perllocal.pod file
rm -rf %{buildroot}%{perl_archlib}
%perl_gen_filelist
install -m 755 anonymize_mailbox %{buildroot}%{_bindir}

%files
%defattr (-, root, root)
%doc README CHANGES LICENSE
%{_mandir}/man?/*
%{_bindir}/anonymize_mailbox
%{_bindir}/grepmail

%changelog
* Tue Feb 27 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Use %%patch -P N instead of deprecated %%patchN.
* Tue Oct 17 2017 dimstar@opensuse.org
- Fix build with perl 5.26.
* Fri May 22 2015 opensuse@cboltz.de
- update to 5.3104 (now hosted on cpan)
- remove upstreamed grepmail_midnight.patch
- remove grepmail-empty-file-not-error.patch (disabled some tests that
  no longer fail)
- disable grepmail-buildfix.patch for > 13.2 (breaks the build for
  factory, but is still needed for <= 13.2)
- update (Build)Requires according to what cpanspec lists
- run spec-cleaner
* Tue Jul 22 2014 mls@suse.de
- do not use bundled File::Spec, it is included in perl-5.20
* Wed Sep 12 2012 coolo@suse.com
- do not overwrite new perl with old perl modules
* Fri Jun 15 2012 opensuse@cboltz.de
- add missing perl(Date::Manip) to requires and buildrequires
* Fri Mar 16 2012 coolo@suse.com
- fix perl requires (and make them buildrequires)
* Tue Jan  4 2011 aj@suse.de
- Make noarch.
- switch to perl_requires macro
* Thu Apr 22 2010 ro@suse.de
- ugly hack to fix build
  (workaround for Mail::Mbox::MessageParser::OLDSTDERR used only
  once)
* Thu Mar  4 2010 ro@suse.de
- fix build with current perl
- there seems to be 5.3034 hosted on google code now (reminder)
* Fri Mar  2 2007 anicka@suse.cz
- update to 5.3033
  * Improved the documentation for -Y.
  * Dropped tzip support in Mail::Mbox::MessageParser
  * Added -L flag to follow symbolic links.
  * Fixed grepmail so that it works with Mail::Mbox::MessageParser
    1.5000
  * Fixed testspeed.pl to properly call report() instead of
    get_report() on new
- remove last patch (fixed in upstream)
* Fri Jan 26 2007 anicka@suse.cz
- fix problems arised with new version of
  perl-Mail-Mbox-MessageParser
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Wed Aug  3 2005 cthiel@suse.de
- update to version 5.3032
- enabled "make test" again
* Tue Aug  2 2005 cthiel@suse.de
- fixed requires
- removed perl-Parse-RecDescent from neededforbuild
- disabled "make test"
* Wed Jul 20 2005 schwab@suse.de
- Skip auto_install.
* Mon Jul 18 2005 rommel@suse.de
- update to version 5.3031
* Mon Jun 21 2004 rommel@suse.de
- update to version 5.30, now requires perl-Mail-Mbox-MessageParser
* Sun Jan 11 2004 adrian@suse.de
- build as user
* Wed Aug 20 2003 mjancar@suse.cz
- require the perl version we build with
* Mon Jul 21 2003 rommel@suse.de
- upgrade to version 5.00
- using perl_vendorlib and perl_vendorarch instead of
  perl_archlib and perl_sitearch
* Tue May 27 2003 mmj@suse.de
- Remove files we don't package
* Fri Jan 17 2003 rommel@suse.de
- update to version 4.91
- removed FastReader (since "it isn't faster anymore")
- added "make test" to build section
* Tue Sep 17 2002 ro@suse.de
- removed bogus self-provides
* Fri Aug 16 2002 rommel@suse.de
- added a patch to remove the superfluous "g" modifier
  from the regular expression matching From-lines
* Mon Jul 29 2002 mls@suse.de
- fixed neededforbuild
* Thu Jan 24 2002 grimmer@suse.de
- Update to 4.70 - from the Changelog:
  o Fixed signal handling to make grepmail easier to debug.
  o Fixed a possible performance problem in reading of emails
  o Expanded the pattern for matching the start of emails to allow
    different types of emails to be parsed.
  o Fixed a bug where -R was reported as not recognized.
  o "anonymize_mailbox" utility included to help people submit bug
    reports
  o If a mailbox can not be found, grepmail now searches the
    $home/mail, $home/Mail, $home/Mailbox directories
  (or the directory specified by the MAIL environment variable).
  o Added -X flag to allow the user to specify a pattern for the
    signature separator.
  o Added -Y flag to search specific headers.
- added anonymize_mailbox to file list
* Tue Nov 13 2001 grimmer@suse.de
- Update to 4.60 - from the Changelog:
  o Removed -B flag and added -S flag. -B is now performed using -bS.
  o Added installation flags to suppress interactive installation.
  o Fixed a slow implementation of searching for signatures that
    would cause grepmail to crawl for very large emails.
  o Fixed a short-circuit which should have bypassed the search for
    signatures if -B was not specified.
  o Implemented a new Perl parser which is 5%% to 50%% faster depending
    on how I/O-bound your system is.
  o Restructured the code a bit and improved detection of invalid
    arguments.
- adjusted build section in spec file to make use of the new
  non-interactive installation option
* Tue Sep 11 2001 grimmer@suse.de
- update to 4.51 (bugfixes) - from the Changelog:
  * grepmail now dies gracefully when invalid patterns like 'strcpy(' are
  supplied. (It should be 'strcpy\('.)
  * Fixed a bug in attachment boundary matching which would cause the
  boundary match to fail if the boundary contained special pattern
  matching characters.
  * Fixed a bug where grepmail would fail to print matching
  emails which had signatures
- bzipped sources
* Wed Aug  1 2001 grimmer@suse.de
- update to 4.50
* Mon Jun 25 2001 ro@suse.de
- added perl-Digest-MD5 perl-Parse-RecDescent to make it build
* Fri Jun 22 2001 grimmer@suse.de
- update to 4.48
- added perl-Inline to neededforbuild
* Wed Apr  4 2001 grimmer@suse.de
- update to 4.47
* Thu Feb 22 2001 grimmer@suse.de
- update to 4.46
- specfile fixes (now uses perl_archlib and perl_sitearch macros)
* Tue Nov 14 2000 grimmer@suse.de
- update to 4.44
- Added Mail::Folder::FastReader module to spec file
- use manpath macro in file list
* Tue Nov  7 2000 grimmer@suse.de
- update to 4.43
- *really* use BuildRoot this time
- added .packlist and perl-module info to file list
- corrected file list since there is only a single executable now
* Mon Jun 19 2000 grimmer@suse.de
- update to 4.41
- added BuildRoot
* Mon Feb 14 2000 grimmer@suse.de
- new version (4.2)
- spec file cleanups (now uses version macro)
- corrected URL and Source URL
* Tue Nov 23 1999 grimmer@suse.de
- initial package (Version 4.1)
